classdef BurgersForce < Source.SourceBase
%BURGERSFORCE   Source term to force the solution to a specific function.
%   If the initial data is chosen to be the function
%      (x,y) -> exp(-k(x^2+y^2))
%   for some k (supplied through the constructor), then this source term will
%   force the (exact) solution to stay constant in time.
	
	properties(Access = private)
		mesh
		k
	end
	
	properties
	end
	
	
	methods
		function o = BurgersForce(k)
			o.k = k;
		end
		
		
		function initialize(o, config)
			o.mesh = config.mesh;
		end
		
		
		function ret = source(o, U, UR, t, dt)
			x = o.mesh.x{1};
			y = o.mesh.x{2};
			
			ret = zeros(size(U));
			ret(o.mesh.internal) = -2*o.k*(x+y).*exp(-2*o.k*(x.^2+y.^2));
% 			for i = 1:size(ret,1)
% 				ret(i,o.mesh.internal) = -2*o.k*(x+y).*exp(-2*o.k*(x.^2+y.^2));
% 			end
		end
	end
end